# librarypython

Módulo para exemplicar a construção de um projeto profissional em Python

Nesse curso é ensinado com contribuir com projetos de código aberto.

Link do curso [Python Pro](https://www.python.pro.br/)

[![Updates](https://pyup.io/repos/github/henriquelima1984/librarypython/shield.svg)](https://pyup.io/repos/github/henriquelima1984/librarypython/)
[![Python 3](https://pyup.io/repos/github/henriquelima1984/librarypython/python-3-shield.svg)](https://pyup.io/repos/github/henriquelima1984/librarypython/)

Suporta versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements.txt
```

Para conferir qualidade do código:

```console
flake8
```

Tópicos a serem abordados:

    1. Git
    2. Virtualenv
    3. Pip